@@ -20,7 +20,7 @@ setMethod('crop', signature(x='Spatial', y='ANY'),
 			y@proj4string <- x@proj4string		
 		}
 		
-		if (! .compareCRS(x, y) ) {
+		if (! compareCRS(x, y) ) {
 			warning('non identical CRS')
 		}
 		y@proj4string <- x@proj4string
