@@ -15,7 +15,7 @@
 		prj <- CRS()
 	} else {
 		projs <- trim(projs)
-		prj <- try(CRS(projs), silent = T)
+		prj <- try(CRS(projs), silent = TRUE)
 		if (class(prj) == "try-error") { 
 			warning(paste(projs, 'is not a valid PROJ.4 CRS string')) 
 			prj <- CRS()
